==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/cs/chinese.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "tuto sobotu",
	"field-sat-relative+1": "příští sobotu",
	"field-dayperiod": "AM/PM",
	"field-sun-relative+-1": "minulou neděli",
	"field-mon-relative+-1": "minulé pondělí",
	"field-minute": "Minuta",
	"field-day-relative+-1": "včera",
	"field-weekday": "Den v týdnu",
	"field-day-relative+-2": "předevčírem",
	"field-era": "Letopočet",
	"field-hour": "Hodina",
	"field-sun-relative+0": "tuto neděli",
	"field-sun-relative+1": "příští neděli",
	"field-wed-relative+-1": "minulou středu",
	"field-day-relative+0": "dnes",
	"field-day-relative+1": "zítra",
	"field-day-relative+2": "pozítří",
	"dateFormat-long": "d. M. y",
	"field-tue-relative+0": "toto úterý",
	"field-zone": "Časové pásmo",
	"field-tue-relative+1": "příští úterý",
	"field-week-relative+-1": "minulý týden",
	"dateFormat-medium": "d. M. y",
	"field-year-relative+0": "tento rok",
	"field-year-relative+1": "příští rok",
	"field-sat-relative+-1": "minulou sobotu",
	"field-year-relative+-1": "minulý rok",
	"field-year": "Rok",
	"field-fri-relative+0": "tento pátek",
	"field-fri-relative+1": "příští pátek",
	"field-week": "Týden",
	"field-week-relative+0": "tento týden",
	"field-week-relative+1": "příští týden",
	"field-month-relative+0": "tento měsíc",
	"field-month": "Měsíc",
	"field-month-relative+1": "příští měsíc",
	"field-fri-relative+-1": "minulý pátek",
	"field-second": "Sekunda",
	"field-tue-relative+-1": "minulé úterý",
	"field-day": "Den",
	"field-mon-relative+0": "toto pondělí",
	"field-mon-relative+1": "příští pondělí",
	"field-thu-relative+0": "tento čtvrtek",
	"field-second-relative+0": "nyní",
	"dateFormat-short": "d. M. y",
	"field-thu-relative+1": "příští čtvrtek",
	"dateFormat-full": "EEEE, d. M. y",
	"field-wed-relative+0": "tuto středu",
	"field-wed-relative+1": "příští středu",
	"field-month-relative+-1": "minulý měsíc",
	"field-thu-relative+-1": "minulý čtvrtek"
}
//end v1.x content
);

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojo/cldr/nls/cs/chinese.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "tuto sobotu",
	"field-sat-relative+1": "příští sobotu",
	"field-dayperiod": "dop./odp.",
	"field-sun-relative+-1": "minulou neděli",
	"field-mon-relative+-1": "minulé pondělí",
	"field-minute": "Minuta",
	"field-day-relative+-1": "včera",
	"field-weekday": "Den v týdnu",
	"field-day-relative+-2": "předevčírem",
	"field-era": "Letopočet",
	"field-hour": "Hodina",
	"field-sun-relative+0": "tuto neděli",
	"field-sun-relative+1": "příští neděli",
	"field-wed-relative+-1": "minulou středu",
	"field-day-relative+0": "dnes",
	"field-day-relative+1": "zítra",
	"field-day-relative+2": "pozítří",
	"dateFormat-long": "d. M. y",
	"field-tue-relative+0": "toto úterý",
	"field-zone": "Časové pásmo",
	"field-tue-relative+1": "příští úterý",
	"field-week-relative+-1": "minulý týden",
	"dateFormat-medium": "d. M. y",
	"field-year-relative+0": "tento rok",
	"field-year-relative+1": "příští rok",
	"field-sat-relative+-1": "minulou sobotu",
	"field-year-relative+-1": "minulý rok",
	"field-year": "Rok",
	"field-fri-relative+0": "tento pátek",
	"field-fri-relative+1": "příští pátek",
	"field-week": "Týden",
	"field-week-relative+0": "tento týden",
	"field-week-relative+1": "příští týden",
	"field-month-relative+0": "tento měsíc",
	"field-month": "Měsíc",
	"field-month-relative+1": "příští měsíc",
	"field-fri-relative+-1": "minulý pátek",
	"field-second": "Sekunda",
	"field-tue-relative+-1": "minulé úterý",
	"field-day": "Den",
	"field-mon-relative+0": "toto pondělí",
	"field-mon-relative+1": "příští pondělí",
	"field-thu-relative+0": "tento čtvrtek",
	"field-second-relative+0": "nyní",
	"dateFormat-short": "d. M. y",
	"field-thu-relative+1": "příští čtvrtek",
	"dateFormat-full": "EEEE, d. M. y",
	"field-wed-relative+0": "tuto středu",
	"field-wed-relative+1": "příští středu",
	"field-month-relative+-1": "minulý měsíc",
	"field-thu-relative+-1": "minulý čtvrtek"
}
//end v1.x content
);
